==> zio-aws-macie2_2.12-5.17.130.2-sources.jar: zio/aws/macie2/model/DisassociateMemberRequest.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.macie2.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class DisassociateMemberRequest(id: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.DisassociateMemberRequest = {
    import DisassociateMemberRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.DisassociateMemberRequest
      .builder()
      .id(__string.unwrap(id): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.DisassociateMemberRequest.ReadOnly =
    zio.aws.macie2.model.DisassociateMemberRequest.wrap(buildAwsValue())
}
object DisassociateMemberRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.DisassociateMemberRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.DisassociateMemberRequest =
      zio.aws.macie2.model.DisassociateMemberRequest(id)
    def id: __string
    def getId: ZIO[Any, Nothing, __string] = ZIO.succeed(id)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.DisassociateMemberRequest
  ) extends zio.aws.macie2.model.DisassociateMemberRequest.ReadOnly {
    override val id: __string =
      zio.aws.macie2.model.primitives.__string(impl.id())
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.DisassociateMemberRequest
  ): zio.aws.macie2.model.DisassociateMemberRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-macie2_2.13-5.20.32.2-sources.jar: zio/aws/macie2/model/DisassociateMemberRequest.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.macie2.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class DisassociateMemberRequest(id: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.DisassociateMemberRequest = {
    import DisassociateMemberRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.DisassociateMemberRequest
      .builder()
      .id(id: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.DisassociateMemberRequest.ReadOnly =
    zio.aws.macie2.model.DisassociateMemberRequest.wrap(buildAwsValue())
}
object DisassociateMemberRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.DisassociateMemberRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.DisassociateMemberRequest =
      zio.aws.macie2.model.DisassociateMemberRequest(id)
    def id: __string
    def getId: ZIO[Any, Nothing, __string] = ZIO.succeed(id)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.DisassociateMemberRequest
  ) extends zio.aws.macie2.model.DisassociateMemberRequest.ReadOnly {
    override val id: __string = impl.id(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.DisassociateMemberRequest
  ): zio.aws.macie2.model.DisassociateMemberRequest.ReadOnly = new Wrapper(impl)
}
